@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.7 2004/03/19 00:02:42 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.9 2004/05/19 18:12:45 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,6 +33,7 @@
 #include <epiphany/ephy-extension.h>
 #include <epiphany/ephy-embed.h>
 #include <epiphany/ephy-tab.h>
+#include <epiphany/ephy-statusbar.h>
 
 #include <gtk/gtkaction.h>
 #include <gtk/gtkactiongroup.h>
@@ -242,10 +243,9 @@ tab_removed_cb (GtkWidget *notebook,
 }
 
 static void
-switch_page_cb (GtkNotebook *notebook,
-		GtkNotebookPage *page,
-		guint page_num,
-		EphyWindow *window)
+sync_active_tab_cb (EphyWindow *window,
+		    GParamSpec *pspec,
+		    EphyCertificatesExtension *extension)
 {
 	EphyTab *tab;
 
@@ -300,7 +300,6 @@ impl_attach_window (EphyExtension *ext,
 	guint ui_id;
 	GtkWidget *notebook;
 	GtkWidget *statusbar, *frame, *ebox;
-	GList *children, *l;
 
 	LOG ("EphyCertificatesExtension attach_window")
 
@@ -309,26 +308,14 @@ impl_attach_window (EphyExtension *ext,
 	g_signal_connect_after (notebook, "tab_added",
 				G_CALLBACK (tab_added_cb), window);
 	g_signal_connect_after (notebook, "tab_removed",
-				G_CALLBACK (tab_added_cb), window);
-	g_signal_connect_after (notebook, "switch_page",
-				G_CALLBACK (switch_page_cb), window);
+				G_CALLBACK (tab_removed_cb), window);
+	g_signal_connect (window, "notify::active-tab",
+			  G_CALLBACK (sync_active_tab_cb), extension);
 
 	/* make padlock icon clickable */
 	statusbar = ephy_window_get_statusbar (window);
 
-	/* FIXME: find a better method to get the security icon frame :) */
-	children = gtk_container_get_children (GTK_CONTAINER (statusbar));
-	for (l = children; l != NULL; l = l->next)
-	{
-		if (GTK_IS_FRAME (l->data) && GTK_IS_EVENT_BOX (GTK_BIN (l->data)->child)) break;
-	}
-	g_return_if_fail (l != NULL);
-
-	ebox = GTK_BIN (l->data)->child;
-	g_list_free (children);
-
-	ebox = GTK_WIDGET (l->data);
-
+	ebox = GTK_BIN (EPHY_STATUSBAR (statusbar)->security_frame)->child;
 	gtk_widget_add_events (ebox, GDK_BUTTON_PRESS_MASK);
 	g_signal_connect (ebox, "button-press-event",
 			  G_CALLBACK (padlock_button_press_cb), window);
